@@ -118,6 +118,8 @@ sphinx_gallery_conf = {
     },
     "jupyterlite": {"notebook_modification_function": notebook_modification_function},
     "examples_dirs": ["../examples/", "../examples_with_rst/", "../examples_rst_index"],
+    "example_extensions": {".py", ".cpp", ".m", ".jl"},
+    "filetype_parsers": {".m": "Matlab"},
     "reset_argv": ResetArgv(),
     "reset_modules": (MockScrapeProblem(), "matplotlib"),
     "gallery_dirs": [
@@ -141,6 +143,7 @@ sphinx_gallery_conf = {
     "exclude_implicit_doc": ["figure_rst"],
     "show_api_usage": True,
     "copyfile_regex": r".*\.rst",
+    "recommender": {"enable": True, "n_examples": 3},
 }
 nitpicky = True
 highlight_language = "python3"
